from setuptools import setup

setup(name='distributions_gj',
      version='0.1',
      description='Gaussian distributions',
      packages=['distributions_gj'],
      author='Gabor Jenei',
      author_email='jeneigabor14@gmail.com',
      zip_safe=False)
